/*
 ChibiOS - Copyright (C) 2006..2016 Giovanni Di Sirio

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

#include "ch.h"
#include "hal.h"
#include "ch_test.h"
#include <string.h>


//#define TRANSMITTER


#define PORT_SPI1_CS_TX                        GPIOB
#define PIN_SPI1_CS_TX                         6


#define PORT_SPI1_SCK                          GPIOA
#define PIN_SPI1_SCK                           5
#define PORT_SPI1_MISO                         GPIOA
#define PIN_SPI1_MISO                          6
#define PORT_SPI1_MOSI                         GPIOA
#define PIN_SPI1_MOSI                          7
/*
 * Configuration for the SPI driver
 */
static const SPIConfig spi_cfg = {NULL,PORT_SPI1_CS_TX, PIN_SPI1_CS_TX};
static uint8_t txbuf[512];
static uint8_t rxbuf[512]={0};
/*
 * Application entry point.
 */
int main(void) {

  /*
   * System initializations.
   * - HAL initialization, this also initializes the configured device drivers
   *   and performs the board-specific initializations.
   * - Kernel initialization, the main() function becomes a thread and the
   *   RTOS is active.
   */
  halInit();
  chSysInit();

  /*
   * SPI1 I/O pins setup.(Overwriting board.h configurations)
   */

  palSetPadMode(PORT_SPI1_SCK, PIN_SPI1_SCK,
                PAL_MODE_ALTERNATE(5) );    /* New SCK */
  palSetPadMode(PORT_SPI1_MISO, PIN_SPI1_MISO,
                PAL_MODE_ALTERNATE(5) );    /* New MISO*/
  palSetPadMode(PORT_SPI1_MOSI, PIN_SPI1_MOSI,
                PAL_MODE_ALTERNATE(5));    /* New MOSI*/

  spiInit();


  palSetPadMode(PORT_SPI1_CS_TX, PIN_SPI1_CS_TX,
                PAL_MODE_OUTPUT_PUSHPULL); /* New CS*/

  palSetPad(PORT_SPI1_CS_TX, PIN_SPI1_CS_TX);
  /*
   * Normal main() thread activity, in this demo it does nothing except
   * sleeping in a loop and check the button state, when the button is
   * pressed the test procedure is launched.
   */

#ifdef TRANSMITTER


    palSetLine(LINE_LED4_BLUE);
    //const char tx_message[]="Hello";
    for (unsigned int i = 0; i < sizeof(txbuf); i++)
      txbuf[i] = (uint8_t)10;

    spiStart(&SPID1, &spi_cfg);
    while (true) {
      if (palReadPad(GPIOA, GPIOA_BUTTON)) {
        /* Acquire ownership of the bus.    */

        spiSelect(&SPID1);

        spiSend(&SPID1, 512, txbuf);

        spiUnselect(&SPID1);

        palToggleLine(LINE_LED10_RED);


      }
      chThdSleepMilliseconds(1);
      //palClearLine(LINE_LED10_RED);

    }
#else

    palSetLine(LINE_LED7_GREEN);


    //char rx_message[5]={0};

    spiStart(&SPID1, &spi_cfg);
    while (true) {
       for (unsigned int i = 0; i < sizeof(rxbuf); i++)
         rxbuf[i] = (uint8_t)0;

       spiSelect(&SPID1);

       spiReceive(&SPID1, 512 , &rxbuf);

       spiUnselect(&SPID1);



       if(rxbuf[0]!=(uint8_t)0){
          palSetLine(LINE_LED5_ORANGE);
        }else{
          palClearLine(LINE_LED5_ORANGE);
        }
      // chThdSleepMilliseconds(00);
    }
#endif

}
